@@ -226,6 +226,7 @@ CREATE TABLE IF NOT EXISTS `zt_host` (
   `memory`       varchar(30)  NOT NULL,
   `diskType`     varchar(30)  NOT NULL,
   `diskSize`     varchar(30)  NOT NULL,
+  `unit`         enum('GB','TB') NOT NULL DEFAULT 'GB',
   `privateIP`    varchar(128) NOT NULL,
   `publicIP`     varchar(128) NOT NULL,
   `nic`          varchar(128) NOT NULL,
@@ -821,47 +822,67 @@ REPLACE INTO `zt_grouppriv` VALUES
 
 ALTER TABLE `zt_workflow` ADD `navigator` varchar(10) NOT NULL AFTER `type`;
 
-INSERT INTO `zt_workflowdatasource` (`type`, `name`, `datasource`) VALUES 
-('system','产品','{\"app\":\"system\",\"module\":\"product\",\"method\":\"getPairs\",\"methodDesc\":\"Get product pairs.\",\"params\":[{\"name\":\"mode\",\"type\":\"string\",\"desc\":\"\",\"value\":\"all\"}]}'),
-('system','项目','{\"app\":\"system\",\"module\":\"project\",\"method\":\"getPairs\",\"methodDesc\":\"Get project pairs.\",\"params\":[{\"name\":\"mode\",\"type\":\"string\",\"desc\":\"all|noclosed or empty\",\"value\":\"all\"}]}'),
-('system','产品线','{\"app\":\"system\",\"module\":\"tree\",\"method\":\"getLinePairs\",\"methodDesc\":\"Get line pairs.\",\"params\":[{\"name\":\"useShort\",\"type\":\"bool\",\"desc\":\"\",\"value\":\"\"}]}'),
-('sql','需求','select id,title from zt_story where deleted=\"0\"'),
-('sql','任务','select id,name from zt_task where deleted=\"0\"'),
-('sql','Bug','select id,title from zt_bug where deleted=\"0\"'),
-('system','权限分组','{\"app\":\"system\",\"module\":\"group\",\"method\":\"getPairs\",\"methodDesc\":\"\",\"params\":[]}'),
-('system','用户','{\"app\":\"system\",\"module\":\"user\",\"method\":\"getPairs\",\"methodDesc\":\"\",\"params\":[{\"name\":\"params\",\"type\":\"\",\"desc\":\"\",\"value\":\"noclosed|noletter\"},{\"name\":\"usersToAppended\",\"type\":\"\",\"desc\":\"\",\"value\":\"\"}]}'),
-('system','产品分支','{\"app\":\"system\",\"module\":\"branch\",\"method\":\"getAllPairs\",\"methodDesc\":\"Get pairs.\",\"params\":[{\"name\":\"params\",\"type\":\"string\",\"desc\":\"\",\"value\":\"\"}]}'),
-('sql','版本','select id,name from zt_build where deleted=\"0\"'),
-('sql','模块','select id,name from zt_module where deleted=\"0\"'),
-('sql','计划','select id,title from zt_productplan where deleted=\"0\"'),
-('lang','产品类型','productType'),
-('lang','产品状态','productStatus'),
-('lang','产品访问控制','productAcl'),
-('lang','项目类型','projectType'),
-('lang','项目状态','projectStatus'),
-('lang','项目访问控制','projectAcl'),
-('lang','发布状态','releaseStatus'),
-('lang','需求来源','storySource'),
-('lang','需求优先级','storyPri'),
-('lang','需求状态','storyStatus'),
-('lang','需求阶段','storyStage'),
-('lang','Bug严重程度','bugSeverity'),
-('lang','Bug优先级','bugPri'),
-('lang','Bug类型','bugType'),
-('lang','Bug操作系统','bugOs'),
-('lang','Bug浏览器','bugBrowser'),
-('lang','Bug状态','bugStatus'),
-('lang','任务类型','taskType'),
-('lang','任务优先级','taskPri'),
-('lang','任务状态','taskStatus'),
-('lang','测试用例优先级','testcasePri'),
-('lang','测试用例类型','testcaseType'),
-('lang','测试用例阶段','testcaseStage'),
-('lang','测试用例状态','testcaseStatus'),
-('lang','测试单优先级','testtaskPri'),
-('lang','测试单状态','testtaskStatus'),
-('lang','反馈状态','feedbackStatus'),
-('lang','Bug解决方案','bugResolution'),
-('sql','用例','select id,title from zt_case where deleted=\"0\"'),
-('system', '反馈分支',  '{\"app\":\"system\",\"module\":\"tree\",\"method\":\"getOptionMenu\",\"methodDesc\":\"Create an option menu in html.\",\"params\":[{\"name\":\"rootID\",\"type\":\"int\",\"desc\":\"\",\"value\":\"0\"},{\"name\":\"type\",\"type\":\"string\",\"desc\":\"\",\"value\":\"feedback\"},{\"name\":\"startModule\",\"type\":\"int\",\"desc\":\"\",\"value\":\"0\"},{\"name\":\"branch\",\"type\":\"\",\"desc\":\"\",\"value\":\"0\"}]}'),
-('lang','需求类型','storyType');
+ALTER TABLE `zt_workflowdatasource` ADD `view` varchar(20) NOT NULL AFTER `datasource`;
+ALTER TABLE `zt_workflowdatasource` ADD `keyField` varchar(50) NOT NULL AFTER `view`;
+ALTER TABLE `zt_workflowdatasource` ADD `valueField` varchar(50) NOT NULL AFTER `keyField`;
+
+INSERT INTO `zt_workflowdatasource` (`type`, `name`, `datasource`, `view`, `keyField`, `valueField`) VALUES
+('system',      '产品', '{\"app\":\"system\",\"module\":\"product\",\"method\":\"getPairs\",\"methodDesc\":\"Get product pairs.\",\"params\":[{\"name\":\"mode\",\"type\":\"string\",\"desc\":\"\",\"value\":\"all\"}]}',       '',     '',     ''),
+('system',      '项目', '{\"app\":\"system\",\"module\":\"project\",\"method\":\"getPairs\",\"methodDesc\":\"Get project pairs.\",\"params\":[{\"name\":\"mode\",\"type\":\"string\",\"desc\":\"all|noclosed or empty\",\"value\":\"all\"}]}',  '',     '',     ''),
+('system',      '产品线',       '{\"app\":\"system\",\"module\":\"tree\",\"method\":\"getLinePairs\",\"methodDesc\":\"Get line pairs.\",\"params\":[{\"name\":\"useShort\",\"type\":\"bool\",\"desc\":\"\",\"value\":\"\"}]}',  '',     '',     ''),
+('sql', '需求', 'select id,title from zt_story where deleted=\"0\"',    'view_datasource_4',    'id',   'title'),
+('sql', '任务', 'select id,name from zt_task where deleted=\"0\"',      'view_datasource_5',    'id',   'name'),
+('sql', 'Bug',  'select id,title from zt_bug where deleted=\"0\"',      'view_datasource_6',    'id',   'title'),
+('system',      '权限分组',     '{\"app\":\"system\",\"module\":\"group\",\"method\":\"getPairs\",\"methodDesc\":\"\",\"params\":[]}',  '',     '',     ''),
+('system',      '用户', '{\"app\":\"system\",\"module\":\"user\",\"method\":\"getPairs\",\"methodDesc\":\"\",\"params\":[{\"name\":\"params\",\"type\":\"\",\"desc\":\"\",\"value\":\"noclosed|noletter\"},{\"name\":\"usersToAppended\",\"type\":\"\",\"desc\":\"\",\"value\":\"\"}]}',        '',     '',     ''),
+('system',      '产品分支',     '{\"app\":\"system\",\"module\":\"branch\",\"method\":\"getAllPairs\",\"methodDesc\":\"Get pairs.\",\"params\":[{\"name\":\"params\",\"type\":\"string\",\"desc\":\"\",\"value\":\"\"}]}',      '',     '',     ''),
+('sql', '版本', 'select id,name from zt_build where deleted=\"0\"',     'view_datasource_10',   'id',   'name'),
+('sql', '模块', 'select id,name from zt_module where deleted=\"0\"',    'view_datasource_11',   'id',   'name'),
+('sql', '计划', 'select id,title from zt_productplan where deleted=\"0\"',      'view_datasource_12',   'id',   'title'),
+('lang',        '产品类型',     'productType',  '',     '',     ''),
+('lang',        '产品状态',     'productStatus',        '',     '',     ''),
+('lang',        '产品访问控制', 'productAcl',   '',     '',     ''),
+('lang',        '项目类型',     'projectType',  '',     '',     ''),
+('lang',        '项目状态',     'projectStatus',        '',     '',     ''),
+('lang',        '项目访问控制', 'projectAcl',   '',     '',     ''),
+('lang',        '发布状态',     'releaseStatus',        '',     '',     ''),
+('lang',        '需求来源',     'storySource',  '',     '',     ''),
+('lang',        '需求优先级',   'storyPri',     '',     '',     ''),
+('lang',        '需求状态',     'storyStatus',  '',     '',     ''),
+('lang',        '需求阶段',     'storyStage',   '',     '',     ''),
+('lang',        'Bug严重程度',  'bugSeverity',  '',     '',     ''),
+('lang',        'Bug优先级',    'bugPri',       '',     '',     ''),
+('lang',        'Bug类型',      'bugType',      '',     '',     ''),
+('lang',        'Bug操作系统',  'bugOs',        '',     '',     ''),
+('lang',        'Bug浏览器',    'bugBrowser',   '',     '',     ''),
+('lang',        'Bug状态',      'bugStatus',    '',     '',     ''),
+('lang',        '任务类型',     'taskType',     '',     '',     ''),
+('lang',        '任务优先级',   'taskPri',      '',     '',     ''),
+('lang',        '任务状态',     'taskStatus',   '',     '',     ''),
+('lang',        '测试用例优先级',       'testcasePri',  '',     '',     ''),
+('lang',        '测试用例类型', 'testcaseType', '',     '',     ''),
+('lang',        '测试用例阶段', 'testcaseStage',        '',     '',     ''),
+('lang',      '测试用例状态', 'testcaseStatus',       '',     '',     ''),
+('lang',      '测试单优先级', 'testtaskPri',  '',     '',     ''),
+('lang',      '测试单状态',   'testtaskStatus',       '',     '',     ''),
+('lang',      '反馈状态',     'feedbackStatus',       '',     '',     ''),
+('lang',      'Bug解决方案',  'bugResolution',        '',     '',     ''),
+('sql',       '用例', 'select id,title from zt_case where deleted=\"0\"',     'view_datasource_41',   'id',   'title'),
+('system',    '反馈分支',     '{\"app\":\"system\",\"module\":\"tree\",\"method\":\"getOptionMenu\",\"methodDesc\":\"Create an option menu in html.\",\"params\":[{\"name\":\"rootID\",\"type\":\"int\",\"desc\":\"\",\"value\":\"0\"},{\"name\":\"type\",\"type\":\"string\",\"desc\":\"\",\"value\":\"feedback\"},{\"name\":\"startModule\",\"type\":\"int\",\"desc\":\"\",\"value\":\"0\"},{\"name\":\"branch\",\"type\":\"\",\"desc\":\"\",\"value\":\"0\"}]}',   '',     '',     ''),
+('lang',      '需求类型',     'storyType',    '',     '',     '');
+
+DROP VIEW IF EXISTS `view_datasource_4`;
+DROP VIEW IF EXISTS `view_datasource_5`;
+DROP VIEW IF EXISTS `view_datasource_6`;
+DROP VIEW IF EXISTS `view_datasource_10`;
+DROP VIEW IF EXISTS `view_datasource_11`;
+DROP VIEW IF EXISTS `view_datasource_12`;
+DROP VIEW IF EXISTS `view_datasource_41`;
+
+CREATE VIEW `view_datasource_4`  AS select `id`,`title` from `zt_story` where `deleted` = '0';
+CREATE VIEW `view_datasource_5`  AS select `id`,`name` from `zt_task` where `deleted` = '0';
+CREATE VIEW `view_datasource_6`  AS select `id`,`title` from `zt_bug` where `deleted` = '0';
+CREATE VIEW `view_datasource_10` AS select `id`,`name` from `zt_build` where `deleted` = '0';
+CREATE VIEW `view_datasource_11` AS select `id`,`name` from `zt_module` where `deleted` = '0';
+CREATE VIEW `view_datasource_12` AS select `id`,`title` from `zt_productplan` where `deleted` = '0';
+CREATE VIEW `view_datasource_41` AS select `id`,`title` from `zt_case` where `deleted` = '0';
