@@ -4,9 +4,9 @@ public function getUsers($deptID, $pager = null, $orderBy = 'id')
     return $this->loadExtension('zentaobiz')->getUsers($deptID, $pager, $orderBy);
 }
 
-public function getDeptUserPairs($deptID = 0)
+public function getDeptUserPairs($deptID = 0, $params = '')
 {
-    return $this->loadExtension('zentaobiz')->getDeptUserPairs($deptID);
+    return $this->loadExtension('zentaobiz')->getDeptUserPairs($deptID, $params);
 }
 
 public function getManager($deptID)
