@@ -22,31 +22,31 @@
 <?php if(commonModel::hasPriv($flow->module, 'search')):?>
 <?php if(empty($this->config->{$flow->module}->search['fields'])):?>
 <li id='searchTab'><?php echo baseHTML::a('#emptySearchModal', "<i class='icon-search icon'></i>" . $lang->search->common, "data-toggle='modal'");?></li>
-<div class='modal fade' id='emptySearchModal'>
-  <div class='modal-dialog'>
-    <div class='modal-content'>
-      <div class='modal-header'>
-        <button type='button' class='close' data-dismiss='modal'><span aria-hidden='true'>×</span></button>
-        <h4 class='modal-title'>
-          <span class='modal-title-name'><?php echo $lang->search->common;?></span>
-        </h4>
-      </div>
-      <div class='modal-body'>
-        <?php
-        if(commonModel::hasPriv('flow.workflowfield', 'setSearch'))
-        {
-            $designLink = baseHTML::a($this->createLink('workflowfield', 'setSearch', "module={$flow->module}"), $lang->flow->setSearch, "target='_parent'");
-        }
-        else
-        {
-            $designLink = $lang->flow->setSearch;
-        }
-        echo "<div class='alert'>" . sprintf($lang->flow->tips->emptySearchFields, $designLink) . '</div>';
-        ?>
+  <div class='modal fade' id='emptySearchModal'>
+    <div class='modal-dialog'>
+      <div class='modal-content'>
+        <div class='modal-header'>
+          <button type='button' class='close' data-dismiss='modal'><span aria-hidden='true'>×</span></button>
+          <h4 class='modal-title'>
+            <span class='modal-title-name'><?php echo $lang->search->common;?></span>
+          </h4>
+        </div>
+        <div class='modal-body'>
+          <?php
+          if(commonModel::hasPriv('flow.workflowfield', 'setSearch'))
+          {
+              $designLink = baseHTML::a($this->createLink('workflowfield', 'setSearch', "module={$flow->module}"), $lang->flow->setSearch, "target='_parent'");
+          }
+          else
+          {
+              $designLink = $lang->flow->setSearch;
+          }
+          echo "<div class='alert'>" . sprintf($lang->flow->tips->emptySearchFields, $designLink) . '</div>';
+          ?>
+        </div>
       </div>
     </div>
   </div>
-</div>
 <?php else:?>
 <li id='bysearchTab'><?php echo baseHTML::a('javascript:;', "<i class='icon-search icon'></i>" . $lang->search->common);?></li>
 <?php endif;?>
@@ -82,6 +82,7 @@ echo $this->flow->buildOperateMenu($flow, $data = null, $type = 'menu');
   <?php if($batchActions && $dataList):?>
   <form id='batchOperateForm' method='post'>
   <?php endif;?>
+  <div class='main-col'>
   <div class='main-table'>
   <table class='table has-sort-head' id="<?php echo $flow->module;?>Table">
     <thead>
@@ -91,7 +92,7 @@ echo $this->flow->buildOperateMenu($flow, $data = null, $type = 'menu');
         <?php foreach($fields as $field):?>
         <?php if(!$field->show) continue;?>
         <?php $width = $field->width && $field->width != 'auto' ? $field->width . 'px' : $field->width;?>
-        <th class="text-<?php echo $field->position;?>" style="width:<?php echo $width;?>">
+        <th class="text-<?php echo $field->position;?> c-<?php echo $field->field;?>" style="width:<?php echo $width;?>">
           <?php if($index == 1 && $batchActions && $dataList):?>
           <div class='checkbox-primary check-all' title='<?php echo $this->lang->selectAll;?>'><label></label></div>
           <?php endif;?>
@@ -124,15 +125,28 @@ echo $this->flow->buildOperateMenu($flow, $data = null, $type = 'menu');
         }
         else
         {
-            if($field->field == 'id')
+            if($field->field == 'id' or $field->field == 'name' or $field->field == 'title')
             {
                 if(commonModel::hasPriv($flow->module, 'view'))
                 {
-                    $output = baseHTML::a(helper::createLink($flow->module, 'view', "dataID={$data->id}"), $data->id);
+                    $output = baseHTML::a(helper::createLink($flow->module, 'view', "dataID={$data->id}"), $data->{$field->field});
                 }
                 else
                 {
-                    $output = $data->id;
+                    $output = $data->{$field->field};
+                }
+            }
+            elseif($field->field == 'assignedTo')
+            {
+                $assignedTo = zget($field->options, $data->{$field->field});
+                $assignedTo = empty($assignedTo) ? $lang->flow->noAssigned : $assignedTo;
+                if(commonModel::hasPriv($flow->module, 'assign') and $this->flow->checkConditions($action, $data))
+                {
+                    $output = baseHTML::a(helper::createLink($flow->module, 'assign', "dataID={$data->id}"), "<i class='icon icon-hand-right'></i> {$assignedTo}", "data-toggle='modal' class='btn btn-icon-left btn-sm'");
+                }
+                else
+                {
+                    $output = $assignedTo;
                 }
             }
             else
@@ -157,6 +171,7 @@ echo $this->flow->buildOperateMenu($flow, $data = null, $type = 'menu');
     </tbody>
   </table>
   </div>
+  </div>
   <div class='table-footer'>
     <?php if($batchActions && $dataList):?>
     <div class='checkbox-primary check-all'><label><?php echo $lang->selectAll?></label></div>
@@ -177,4 +192,7 @@ echo $this->flow->buildOperateMenu($flow, $data = null, $type = 'menu');
 </div>
 <?php if(!empty($flow->js)) js::execute($flow->js);?>
 <?php if(!empty($action->js)) js::execute($action->js);?>
+<script>
+<?php echo file_get_contents(dirname(dirname(__FILE__)) . '/js/search.js');?>
+</script>
 <?php include '../../' . 'common/view/footer.html.php';?>
