@@ -49,7 +49,7 @@ class repo extends control
     {
         $repoID = $this->session->repoID;
         $this->repo->setMenu($this->repos, $repoID, false);
-        if(common::hasPriv('repo', 'create')) $this->lang->modulePageActions = html::a(helper::createLink('repo', 'create'), "<i class='icon icon-plus'></i> " . $this->lang->repo->create, '', "class='btn btn-primary'");
+        if(common::hasPriv('repo', 'create')) $this->lang->TRActions = html::a(helper::createLink('repo', 'create'), "<i class='icon icon-plus'></i> " . $this->lang->repo->create, '', "class='btn btn-primary'");
 
         $this->app->loadClass('pager', $static = true);
         $pager = new pager($recTotal, $recPerPage, $pageID);
@@ -174,18 +174,27 @@ class repo extends control
      */
     public function view($repoID, $entry, $revision = 'HEAD', $showBug = 'false', $encoding = '')
     {
-        if($this->get->entry) $entry = $this->get->entry;
+        if($this->get->repoPath) $entry = $this->get->repoPath;
         $this->repo->setMenu($this->repos, $repoID);
         $this->repo->setBackSession('view', $withOtherModule = true);
         if($repoID == 0) $repoID = $this->session->repoID;
 
+        if($_POST)
+        {
+            $oldRevision = isset($this->post->revision[1]) ? $this->post->revision[1] : '';
+            $newRevision = isset($this->post->revision[0]) ? $this->post->revision[0] : '';
+
+            $this->locate($this->repo->createLink('diff', "repoID=$repoID&entry=$entry&oldrevision=$oldRevision&newRevision=$newRevision"));
+        }
+
         $file  = $entry;
         $repo  = $this->repo->getRepoByID($repoID);
         $entry = $this->repo->decodePath($entry);
 
         $this->scm->setEngine($repo);
         $info = $this->scm->info($entry, $revision);
-        if($info->kind == 'dir') $this->locate($this->repo->createLink('browse', "repoID=$repoID&path=&revision=$revision", "path=" . $this->repo->encodePath($info->path)));
+        $path = $entry ? $info->path : '';
+        if($info->kind == 'dir') $this->locate($this->repo->createLink('browse', "repoID=$repoID&path=" . $this->repo->encodePath($path) . "&revision=$revision"));
         $content  = $this->scm->cat($entry, $revision);
         $entry    = urldecode($entry);
         $pathInfo = pathinfo($entry); 
@@ -263,19 +272,25 @@ class repo extends control
      */
     public function browse($repoID = 0, $path = '', $revision = 'HEAD', $refresh = 0)
     {
-        if($this->get->path) $path = $this->get->path;
+        /* Get path and refresh. */
+        if($this->get->repoPath) $path = $this->get->repoPath;
         if(empty($refresh) and $this->cookie->repoRefresh) $refresh = $this->cookie->repoRefresh;
+
+        /* Set menu and session. */
         $this->repo->setMenu($this->repos, $repoID);
         $this->repo->setBackSession('list', $withOtherModule = true);
         if($repoID == 0) $repoID = $this->session->repoID;
 
+        /* Get repo and synchronous commit. */
         $repo = $this->repo->getRepoByID($repoID);
         if(!$repo->synced) $this->locate($this->repo->createLink('showSyncCommit', "repoID=$repoID"));
 
+        /* Decrypt path and get cacheFile. */
         $path      = $this->repo->decodePath($path);
         $cacheFile = $this->repo->getCacheFile($repoID, $path, $revision);
         $this->scm->setEngine($repo);
 
+        /* Load pager. */
         $this->app->loadClass('pager', $static = true);
         $pager = new pager(0, 8, 1);
 
@@ -284,16 +299,28 @@ class repo extends control
             $oldRevision = isset($this->post->revision[1]) ? $this->post->revision[1] : '';
             $newRevision = isset($this->post->revision[0]) ? $this->post->revision[0] : '';
 
-            $this->locate( $this->repo->createLink('diff', "repoID=$repoID&entry=" . $this->repo->encodePath(urldecode($path)) . "&oldrevision=$oldRevision&newRevision=$newRevision"));
+            $this->locate($this->repo->createLink('diff', "repoID=$repoID&entry=" . $this->repo->encodePath($path) . "&oldrevision=$oldRevision&newRevision=$newRevision"));
         }
 
         /* Cache infos. */
         if($refresh or !$cacheFile or !file_exists($cacheFile) or (time() - filemtime($cacheFile)) / 60 > $this->config->repo->cacheTime)
         {
+            /* Get cache infos. */
             $infos = $this->scm->ls($path, $revision);
 
-            if($infos and $repo->SCM == 'Subversion')
+            if($infos)
             {
+                /* Update code commit history. */
+                $commentGroup = $this->loadModel('job')->getTriggerGroup('commit', array($repo->id));
+
+                if($refresh and $repo->SCM == 'Git')
+                {
+                    $branch = $this->cookie->repoBranch;
+                    $this->loadModel('git')->updateCommit($repo, $commentGroup, false);
+                    $_COOKIE['repoBranch'] = $branch;
+                }
+                if($refresh and $repo->SCM == 'Subversion') $this->loadModel('svn')->updateCommit($repo, $commentGroup, false);
+
                 $revisionList = array();
                 foreach($infos as $info) $revisionList[$info->revision] = $info->revision;
                 $comments = $this->repo->getHistory($repoID, $revisionList);
@@ -323,9 +350,12 @@ class repo extends control
         }
         if($this->cookie->repoRefresh) setcookie('repoRefresh', 0, 0, $this->config->webRoot);
 
+        /* Set logType and revisions and synchronous commit. */
         $logType   = 'dir';
         $revisions = $this->repo->getCommits($repo, $path, $revision, $logType, $pager);
         if($repo->SCM == 'Git' and $infos and empty($revisions)) $this->locate($this->repo->createLink('showSyncCommit', "repoID=$repoID&branch=" . base64_encode($this->cookie->repoBranch)));
+
+        /* Set committers. */
         $commiters = $this->loadModel('user')->getCommiters();
         foreach($infos as $info) $info->committer = zget($commiters, $info->account, $info->account);
         foreach($revisions as $log) $log->committer = zget($commiters, $log->committer, $log->committer);
@@ -359,7 +389,7 @@ class repo extends control
      */
     public function log($repoID = 0, $entry = '', $revision = 'HEAD', $type = 'dir', $recTotal = 0, $recPerPage = 50, $pageID = 1)
     {
-        if($this->get->entry) $entry = $this->get->entry;
+        if($this->get->repoPath) $entry = $this->get->repoPath;
         $this->repo->setMenu($this->repos, $repoID);
         $this->repo->setBackSession('log', $withOtherModule = true);
         if($repoID == 0) $repoID = $this->session->repoID;
@@ -376,7 +406,7 @@ class repo extends control
             $oldRevision = isset($this->post->revision[1]) ? $this->post->revision[1] : '';
             $newRevision = isset($this->post->revision[0]) ? $this->post->revision[0] : '';
 
-            $this->locate( $this->repo->createLink('diff', "repoID=$repoID&entry=" . $this->repo->encodePath(urldecode($path)) . "&oldrevision=$oldRevision&newRevision=$newRevision"));
+            $this->locate($this->repo->createLink('diff', "repoID=$repoID&entry=" . $this->repo->encodePath($path) . "&oldrevision=$oldRevision&newRevision=$newRevision"));
         }
 
         $this->scm->setEngine($repo);
@@ -404,7 +434,7 @@ class repo extends control
      *
      * @param int    $repoID
      * @param int    $revision
-     * @param string $path
+     * @param string $root
      * @param string $type
      *
      * @access public
@@ -412,6 +442,8 @@ class repo extends control
      */
     public function revision($repoID, $revision, $root = '', $type = 'dir')
     {
+        if($this->get->repoPath) $root = $this->get->repoPath;
+
         $this->repo->setMenu($this->repos, $repoID);
         $this->repo->setBackSession();
         if($repoID == 0) $repoID = $this->session->repoID;
@@ -453,13 +485,13 @@ class repo extends control
             $encodePath = $this->repo->encodePath($path);
             if($change['kind'] == '' or $change['kind'] == 'file')
             {
-                $change['view'] = $viewPriv ? html::a($this->repo->createLink('view', "repoID=$repoID&entry=&revision=$revision", "entry=$encodePath"), $this->lang->repo->viewA) : '';
-                if($change['action'] == 'M') $change['diff'] = $diffPriv ? html::a($this->repo->createLink('diff', "repoID=$repoID&entry=&oldRevision=$oldRevision&newRevision=$revision", "entry=$encodePath"), $this->lang->repo->diffAB) : '';
+                $change['view'] = $viewPriv ? html::a($this->repo->createLink('view', "repoID=$repoID&entry=$encodePath&revision=$revision"), $this->lang->repo->viewA) : '';
+                if($change['action'] == 'M') $change['diff'] = $diffPriv ? html::a($this->repo->createLink('diff', "repoID=$repoID&entry=$encodePath&oldRevision=$oldRevision&newRevision=$revision"), $this->lang->repo->diffAB) : '';
             }
             else
             {
-                $change['view'] = $viewPriv ? html::a($this->repo->createLink('browse', "repoID=$repoID&path=&revision=$revision", "path=$encodePath"), $this->lang->repo->browse) : '';
-                if($change['action'] == 'M') $change['diff'] = $diffPriv ? html::a($this->repo->createLink('diff', "repoID=$repoID&entry=&oldRevision=$oldRevision&newRevision=$revision", "entry=$encodePath"), $this->lang->repo->diffAB) : '';
+                $change['view'] = $viewPriv ? html::a($this->repo->createLink('browse', "repoID=$repoID&path=$encodePath&revision=$revision"), $this->lang->repo->browse) : '';
+                if($change['action'] == 'M') $change['diff'] = $diffPriv ? html::a($this->repo->createLink('diff', "repoID=$repoID&entry=$encodePath&oldRevision=$oldRevision&newRevision=$revision"), $this->lang->repo->diffAB) : '';
             }
             $changes[$path] = $change;
         }
@@ -505,7 +537,7 @@ class repo extends control
      */
     public function blame($repoID, $entry, $revision = 'HEAD', $encoding = '')
     {
-        if($this->get->entry) $entry = $this->get->entry;
+        if($this->get->repoPath) $entry = $this->get->repoPath;
         $this->repo->setMenu($this->repos, $repoID);
         if($repoID == 0) $repoID = $this->session->repoID;
         $repo  = $this->repo->getRepoByID($repoID);
@@ -552,7 +584,7 @@ class repo extends control
      */
     public function diff($repoID, $entry = '', $oldRevision = '0', $newRevision = 'HEAD', $showBug = 'false', $encoding = '')
     {
-        if($this->get->entry) $entry = $this->get->entry;
+        if($this->get->repoPath) $entry = $this->get->repoPath;
         $this->repo->setMenu($this->repos, $repoID);
         if($repoID == 0) $repoID = $this->session->repoID;
         $file    = $entry;
@@ -576,7 +608,7 @@ class repo extends control
             }
             if($this->post->encoding) $encoding = $this->post->encoding;
 
-            $this->locate( $this->repo->createLink('diff', "repoID=$repoID&entry=$entry&oldrevision=$oldRevision&newRevision=$newRevision&showBug=&encoding=$encoding"));
+            $this->locate($this->repo->createLink('diff', "repoID=$repoID&entry=" . $this->repo->encodePath($entry) . "&oldrevision=$oldRevision&newRevision=$newRevision&showBug=&encoding=$encoding"));
         }
 
         $this->scm->setEngine($repo);
@@ -659,7 +691,7 @@ class repo extends control
      */
     public function download($repoID, $path, $fromRevision = 'HEAD', $toRevision = '', $type = 'file')
     {
-        if($this->get->path) $path = $this->get->path;
+        if($this->get->repoPath) $path = $this->get->repoPath;
         $entry = $this->repo->decodePath($path);
         $repo  = $this->repo->getRepoByID($repoID);
         $this->scm->setEngine($repo);
@@ -874,7 +906,7 @@ class repo extends control
      */
     public function ajaxSideCommits($repoID, $path, $type = 'dir', $recTotal = 0, $recPerPage = 8, $pageID = 1)
     {
-        if($this->get->path) $path = $this->get->path;
+        if($this->get->repoPath) $path = $this->get->repoPath;
         $this->app->loadClass('pager', $static = true);
         $pager = new pager($recTotal, $recPerPage, $pageID);
 
