@@ -30,4 +30,4 @@ $lang->workflowlabel->error->emptyParams = '檢索條件不能為空！';
 
 $lang->workflowlabel->placeholder = new stdclass();
 $lang->workflowlabel->placeholder->known    = '知道了';
-$lang->workflowlabel->placeholder->features = '流程列表頁的標籤，用於在流程的列表頁可以通過這些標籤查看和瀏覽。';
+$lang->workflowlabel->placeholder->features = '在流程的列表頁可以通過這些標籤查看和瀏覽。';
