@@ -36,7 +36,7 @@
       <?php if($required):?>
       <span class='text-muted'><?php echo '(' . $lang->workflowlayout->require . ')';?></span>
       <?php endif;?>
-      <?php if($action->action != 'browse' && $action->action != 'view' && !is_numeric($key)):?>
+      <?php if($action->action != 'browse' && $action->action != 'view' && !is_numeric($key) && $action->action != 'admin' && $action->action != 'adminview'):?>
 
       <?php /* Layout rules. */ ?>
       <span>
@@ -51,7 +51,7 @@
         <?php
         if($field->control == 'multi-select' or $field->control == 'checkbox')
         {
-            echo html::select("defaultValue[$key][]", $field->options, $field->defaultValue, "class='form-control chosen' multiple='multiple' $disabled");
+            echo str_replace('picker-select', 'chosen', html::select("defaultValue[$key][]", $field->options, $field->defaultValue, "class='form-control chosen' multiple='multiple' $disabled"));
         }
         else
         {
@@ -69,8 +69,7 @@
         $checked = '';
         if(!in_array($field->control, $controlList))
         {
-            $checked  = "checked='checked'";
-            $disabled = "disabled='disabled'";
+            $checked  = "checked='checked' disabled='disabled'";
         }
         if(in_array($field->control, $controlList) && !empty($field->defaultValue) && !isset($field->options[$field->defaultValue])) $checked = "checked='checked'";
         ?>
@@ -95,7 +94,7 @@
       <?php endif;?>
 
       <?php /* Width. */ ?>
-      <?php if($action->action == 'browse' or ($action->type == 'batch' && $action->batchMode == 'different')):?>
+      <?php if($action->action == 'browse' or ($action->module == 'feedback' && $action->action == 'admin') or ($action->type == 'batch' && $action->batchMode == 'different')):?>
       <span>
         <span class='text-muted'><?php echo $lang->workflowlayout->width;?></span>
         <?php echo html::input("width[$key]", $field->width, "class='form-control' $disabled");?>
@@ -109,13 +108,18 @@
       <?php endif;?>
 
       <?php /* Position. */ ?>
-      <?php if($action->action == 'view' or $action->action == 'browse' or $action->layout == 'side'):?>
+      <?php if($action->action == 'view' or $action->action == 'browse' or $action->layout == 'side' or ($action->module == 'feedback' and ($action->action == 'adminview' or $action->action == 'admin'))):?>
       <span>
         <span class='text-muted'><?php echo $lang->workflowlayout->position;?></span>
         <?php if($action->action == 'view' and $index == 1):?>
         <a data-toggle='tooltip' class='position-tips' title='<?php echo $lang->workflowlayout->tips->position;?>'><i class='icon-question-sign'></i></a>
         <?php endif;?>
-        <?php echo html::select("position[$key]", $lang->workflowlayout->positionList[$action->action], !empty($field->position) ? $field->position : zget($defaultPositions, $field->field, ''), "class='form-control' $disabled");?>
+        <?php
+        $actionName = $action->action;
+        if($action->module == 'feedback' and $action->action == 'adminview') $actionName = 'view';
+        if($action->module == 'feedback' and $action->action == 'admin') $actionName = 'browse';
+        ?>
+        <?php echo html::select("position[$key]", $lang->workflowlayout->positionList[$actionName], !empty($field->position) ? $field->position : zget($defaultPositions, $field->field, ''), "class='form-control' $disabled");?>
       </span>
       <?php endif;?>
 
