@@ -1,3 +1,4 @@
+<?php if(!empty($config->URAndSR) and $type == 'requirement'):?>
 <?php
 $storyName = $type == 'requirement' ? $lang->URCommon : $lang->SRCommon;
 $lang->story->source = str_replace($lang->storyCommon, $storyName, $lang->story->source);
@@ -11,9 +12,10 @@ $(function()
     $('#batchCreateForm table thead tr:first').find('th').eq(5).html('<?php echo $lang->story->spec;?>');
     $('#batchCreateForm table thead tr:first th.col-plan').remove();
     $('#batchCreateForm table thead tr:first').find('th').eq(6).html('<?php echo $lang->story->source;?>');
-    $('#footer .breadcrumb li').eq(3).html($('#footer .breadcrumb li').eq(3).html().replace('<?php echo $lang->storyCommon;?>', '<?php echo $storyName;?>'));
+    if($('#footer .breadcrumb li').length > 0) $('#footer .breadcrumb li').eq(3).html($('#footer .breadcrumb li').eq(3).html().replace('<?php echo $lang->storyCommon;?>', '<?php echo $storyName;?>'));
     $('#batchCreateForm table tbody tr').each(function(){ $(this).find('[id^=plan]').closest('td').remove();});
     var colspan = $('#batchCreateForm table tfoot tr:first td:first').attr('colspan');
     $('#batchCreateForm table tfoot tr:first td:first').attr('colspan', colspan - 1);
 })
 </script>
+<?php endif;?>
