@@ -2,12 +2,12 @@
 <?php $methodName = $this->app->getMethodName();?>
 <?php if(common::hasPriv('user', 'todocalendar')):?>
 <script>
-$('#mainMenu .todoTab').attr('href', <?php echo json_encode(inlink('todocalendar', "account=$account"));?>);
+$('#mainMenu .todoTab').attr('href', <?php echo json_encode(inlink('todocalendar', "userID={$user->id}"));?>);
 </script>
 <?php endif;?>
 <?php if(common::hasPriv('user', 'effortcalendar') and !common::hasPriv('user', 'todocalendar')):?>
 <script>
-$('#mainMenu .todoTab').attr('href', <?php echo json_encode(inlink('effortcalendar', "account=$account"));?>);
+$('#mainMenu .todoTab').attr('href', <?php echo json_encode(inlink('effortcalendar', "userID={$user->id}"));?>);
 </script>
 <?php endif;?>
 <script>
